require 'test_helper'

class PoiTest < MiniTest::Test
  def test_create
    VCR.use_cassette('geodata/poi/create') do
      result = BaiduLBS::Geodata::Poi.create(title: 'awesome_poi',
                                             longitude: 100,
                                             latitude: 100,
                                             coord_type: 1,
                                             geotable_id: 78835)
      assert_equal 0, result['status']
    end
  end

  def test_list
    VCR.use_cassette('geodata/poi/list') do
      result = BaiduLBS::Geodata::Poi.list(geotable_id: 78835, title: 'awesome_poi')

      assert_equal 'awesome_poi', result['pois'].first['title']
    end
  end

  def test_detail
    VCR.use_cassette('geodata/poi/detail') do
      result = BaiduLBS::Geodata::Poi.detail(geotable_id: 78835, id: 499219466)

      assert_equal 'awesome_poi', result['poi']['title']
    end
  end

  def test_update
    VCR.use_cassette('geodata/poi/update') do
      result = BaiduLBS::Geodata::Poi.update(geotable_id: 78835, id: 499219466, title: 'cool_poi')

      assert_equal 0, result['status']
    end
  end

  def test_delete
    VCR.use_cassette('geodata/poi/delete') do
      result = BaiduLBS::Geodata::Poi.detail(geotable_id: 78835, id: 499219466)

      assert_equal 0, result['status']
    end
  end

  def test_upload
    VCR.use_cassette('geodata/poi/upload') do
      result = BaiduLBS::Geodata::Poi.upload(geotable_id: 78835,
                                             poi_list: File.expand_path('../../../fixtures/poi_list.csv', __FILE__))
      assert_equal 0, result['status']
    end
  end
end
